@@ -14,7 +14,6 @@ class AcceptContainer():
         if accept_header_string:
             self.parse(accept_header_string)
             
-            
     def parse(self, accept_header_string):
         """Parse the accept header string into the object
         """
@@ -28,9 +27,9 @@ class AcceptContainer():
             # Split the accept_param to see if a quality factor is present
             (key, _, quality_factor) = accept_param.partition(';')
                        
-            if quality_factor:
+            if "q=" in quality_factor:
                 # Quality factor is present, parse it
-                self.accepts[key] = float(quality_factor.partition('=')[2])
+                self.accepts[key] = float(quality_factor.partition('q=')[2])
             else:
                 # No quality factor present, so 1.0 is assumed per HTTP/1.1 specifications
-                self.accepts[key] = 1.0
\ No newline at end of file
+                self.accepts[key] = 1.0
